@@ -33,4 +33,14 @@ class WebScraper:
 
     class Properties:
         TEXT = 'text()'
-        HTML = 'html()'
\ No newline at end of file
+        HTML = 'html()'
+
+class Requests:
+
+    class Types:
+        POST = 'POST'
+        GET = 'GET'
+    
+    class Responses:
+        TEXT = 'TEXT'
+        JSON = 'JSON'
